@@ -32,6 +32,8 @@ spark_config_settings <- function() {
     sparklyr.gateway.config.retries = "Number of retries to retrieve port and address from config, useful when using functions to query port or address in kubernetes.",
     sparklyr.gateway.interval = "Total of seconds sparkyr will check on a gateway connection.",
     sparklyr.gateway.port = "The port the sparklyr gateway uses in the driver machine, defaults to 8880.",
+    sparklyr.gateway.port.query.attempts = "Max number of attempts to query Sparklyr gateway ports.",
+    sparklyr.gateway.port.query.retry.interval.seconds = "Number of seconds between two consecutive Sparklyr gateway ports query attempts.",
     sparklyr.gateway.remote = "Should the sparklyr gateway allow remote connections? This is required in yarn cluster, etc.",
     sparklyr.gateway.routing = "Should the sparklyr gateway service route to other sessions? Consider disabling in kubernetes.",
     sparklyr.gateway.service = "Should the sparklyr gateway be run as a service without shutting down when the last connection disconnects?",
@@ -41,6 +43,8 @@ spark_config_settings <- function() {
     sparklyr.livy.branch = "GitHub branch to be used to deploy sparklyr JAR to Livy.",
     sparklyr.livy.jar = "URL or path to the sparklyr JAR to be used by Livy.",
     sparklyr.livy.headers = "Additional HTTP headers for Livy connections.",
+    sparklyr.livy.proxy = "Optional HTTP proxy setting for Livy connections (any non-default value must be specified via httr::use_proxy()).",
+    sparklyr.livy.additional_curl_opts = "Additional CURL options for Livy connections (see httr::httr_options() for a list of valid options).",
     sparklyr.livy.sources = "Should sparklyr sources be sourced when connecting? If false, manually register sparklyr jars.",
     sparklyr.log.invoke = "Should every call to invoke() be printed in the console? Can be set to 'callstack' to log call stack.",
     sparklyr.log.console = "Should driver logs be printed in the console?",
