@@ -1,7 +1,6 @@
 # nocov start
 
-connection_progress_update <- function(jobName, progressUnits, url)
-{
+connection_progress_update <- function(jobName, progressUnits, url) {
   jobActions <- NULL
   if (nchar(url) > 0) {
     jobActions <- list(
@@ -18,23 +17,26 @@ connection_progress_update <- function(jobName, progressUnits, url)
   )
 }
 
-connection_progress_base <- function(sc, terminated = FALSE)
-{
+connection_progress_base <- function(sc, terminated = FALSE) {
   env <- sc$state$progress
   api <- rstudio_jobs_api()
 
-  if (is.null(env$jobs))
+  if (is.null(env$jobs)) {
     env$jobs <- list()
+  }
 
   if ((!terminated || length(env$jobs) > 0) &&
-      !is.null(spark_context(sc))) {
+    !is.null(spark_context(sc))) {
     connection_progress_context(sc, function() {
       if (is.null(env$web_url)) {
-        env$web_url <- tryCatch({
-          spark_web(sc)
-        }, error = function(e) {
-          ""
-        })
+        env$web_url <- tryCatch(
+          {
+            spark_web(sc)
+          },
+          error = function(e) {
+            ""
+          }
+        )
       }
 
       tracker <- invoke(spark_context(sc), "statusTracker")
@@ -46,8 +48,7 @@ connection_progress_base <- function(sc, terminated = FALSE)
         if (!jobId %in% names(env$jobs)) {
           jobIdText <- ""
           jobInfoOption <- invoke(tracker, "getJobInfo", as.integer(jobId))
-          if (invoke(jobInfoOption, "nonEmpty"))
-          {
+          if (invoke(jobInfoOption, "nonEmpty")) {
             jobInfo <- invoke(jobInfoOption, "get")
             jobSparkId <- invoke(jobInfo, "jobId")
             jobIdText <- paste("(", jobSparkId, ")", sep = "")
@@ -66,8 +67,7 @@ connection_progress_base <- function(sc, terminated = FALSE)
       # remove or update jobs
       for (jobId in names(env$jobs)) {
         jobInfoOption <- invoke(tracker, "getJobInfo", as.integer(jobId))
-        if (invoke(jobInfoOption, "nonEmpty"))
-        {
+        if (invoke(jobInfoOption, "nonEmpty")) {
           jobInfo <- invoke(jobInfoOption, "get")
           jobStatus <- invoke(invoke(jobInfo, "status"), "toString")
 
@@ -88,13 +88,13 @@ connection_progress_base <- function(sc, terminated = FALSE)
   }
 
   if (terminated) {
-    for (jobId in names(env$jobs))
+    for (jobId in names(env$jobs)) {
       api$add_job_progress(env$jobs[[jobId]]$ref, 100L)
+    }
   }
 }
 
-connection_progress_context <- function(sc, f)
-{
+connection_progress_context <- function(sc, f) {
   sc$state$use_monitoring <- TRUE
   on.exit(sc$state$use_monitoring <- FALSE)
 
@@ -103,25 +103,27 @@ connection_progress_context <- function(sc, f)
   f()
 }
 
-connection_progress <- function(sc, terminated = FALSE)
-{
+connection_progress <- function(sc, terminated = FALSE) {
   if (!spark_config_logical(sc$config, "sparklyr.progress", TRUE) ||
-      !rstudio_jobs_api_available() ||
-      identical(sc$state$use_monitoring, TRUE))
+    !rstudio_jobs_api_available() ||
+    identical(sc$state$use_monitoring, TRUE)) {
     return()
+  }
 
-  tryCatch({
-    connection_progress_base(sc, terminated)
-  }, error = function(e) {
-    # ignore all connection progress errors
-    if (spark_config_value(sc$config, "sparklyr.verbose", FALSE)) {
-      warning("Error while checking job progress: ", e$message)
+  tryCatch(
+    {
+      connection_progress_base(sc, terminated)
+    },
+    error = function(e) {
+      # ignore all connection progress errors
+      if (spark_config_value(sc$config, "sparklyr.verbose", FALSE)) {
+        warning("Error while checking job progress: ", e$message)
+      }
     }
-  })
+  )
 }
 
-connection_progress_terminated <- function(sc)
-{
+connection_progress_terminated <- function(sc) {
   connection_progress(sc, terminated = TRUE)
 }
 
