@@ -36,15 +36,17 @@ setMethod("dbQuoteLiteral", "spark_connection", function(conn, x, ...) {
 })
 
 get_data_type <- function(obj) {
-  if (is.factor(obj)) return("TEXT")
+  if (is.factor(obj)) {
+    return("TEXT")
+  }
 
   switch(typeof(obj),
-         integer = "INTEGER",
-         double = "REAL",
-         character = "STRING",
-         logical = "INTEGER",
-         list = "BLOB",
-         stop("Unsupported type", call. = FALSE)
+    integer = "INTEGER",
+    double = "REAL",
+    character = "STRING",
+    logical = "INTEGER",
+    list = "BLOB",
+    stop("Unsupported type", call. = FALSE)
   )
 }
 
@@ -65,8 +67,7 @@ setMethod("dbQuoteString", c("spark_connection", "character"), function(conn, x,
 })
 
 # Sets a property for the connection
-setGeneric("dbSetProperty", function(conn, property, value) standardGeneric("dbSetProperty"));
-
+setGeneric("dbSetProperty", function(conn, property, value) standardGeneric("dbSetProperty"))
 # Sets a property for the connection
 setMethod("dbSetProperty", c("spark_connection", "character", "character"), function(conn, property, value) {
   dbGetQuery(
