@@ -1,12 +1,16 @@
+#' @include dplyr_hof.R
+NULL
+
 #' @export
 #' @importFrom dplyr sql_escape_ident
 #' @importFrom dbplyr sql_quote
 sql_escape_ident.spark_connection <- function(con, x) {
   # Assuming it might include database name like: `dbname.tableName`
-  if (length(x) == 1)
+  if (length(x) == 1) {
     tbl_quote_name(con, x)
-  else
-    dbplyr::sql_quote(x, '`')
+  } else {
+    dbplyr::sql_quote(x, "`")
+  }
 }
 
 #' @importFrom dbplyr sql
@@ -14,7 +18,9 @@ build_sql_if_compare <- function(..., con, compare) {
   args <- list(...)
 
   build_sql_if_parts <- function(ifParts, ifValues) {
-    if(length(ifParts) == 1) return(ifParts[[1]])
+    if (length(ifParts) == 1) {
+      return(ifParts[[1]])
+    }
 
     current <- ifParts[[1]]
     currentName <- ifValues[[1]]
@@ -56,7 +62,6 @@ build_sql_if_compare <- function(..., con, compare) {
 #' @importFrom dbplyr win_current_order
 sql_translate_env.spark_connection <- function(con) {
   win_recycled_params <- function(prefix) {
-
     function(x, y) {
       # Use win_current_frame() once exported form `dbplyr`
       sql_context <- get("sql_context", envir = asNamespace("dbplyr"))
@@ -72,26 +77,102 @@ sql_translate_env.spark_connection <- function(con) {
   }
 
   dbplyr::sql_variant(
-
     scalar = dbplyr::sql_translator(
       .parent = dbplyr::base_scalar,
       as.numeric = function(x) dbplyr::build_sql("CAST(", x, " AS DOUBLE)"),
-      as.double  = function(x) dbplyr::build_sql("CAST(", x, " AS DOUBLE)"),
-      as.integer  = function(x) dbplyr::build_sql("CAST(", x, " AS INT)"),
+      as.double = function(x) dbplyr::build_sql("CAST(", x, " AS DOUBLE)"),
+      as.integer = function(x) dbplyr::build_sql("CAST(", x, " AS INT)"),
       as.logical = function(x) dbplyr::build_sql("CAST(", x, " AS BOOLEAN)"),
-      as.character  = function(x) dbplyr::build_sql("CAST(", x, " AS STRING)"),
-      as.date  = function(x) dbplyr::build_sql("CAST(", x, " AS DATE)"),
-      as.Date  = function(x) dbplyr::build_sql("CAST(", x, " AS DATE)"),
+      as.character = function(x) dbplyr::build_sql("CAST(", x, " AS STRING)"),
+      as.date = function(x) dbplyr::build_sql("CAST(", x, " AS DATE)"),
+      as.Date = function(x) dbplyr::build_sql("CAST(", x, " AS DATE)"),
       paste = function(..., sep = " ") dbplyr::build_sql("CONCAT_WS", list(sep, ...)),
       paste0 = function(...) dbplyr::build_sql("CONCAT", list(...)),
       xor = function(x, y) dbplyr::build_sql(x, " ^ ", y),
-      or = function(x, y) dbplyr::build_sql(x, " or ", y),
-      and = function(x, y) dbplyr::build_sql(x, " and ", y),
+      or = function(x, y) dbplyr::build_sql(x, " OR ", y),
+      and = function(x, y) dbplyr::build_sql(x, " AND ", y),
       pmin = function(...) build_sql_if_compare(..., con = con, compare = "<="),
       pmax = function(...) build_sql_if_compare(..., con = con, compare = ">="),
-      `%like%` = function(x, y) dbplyr::build_sql(x, " like ", y),
-      `%rlike%` = function(x, y) dbplyr::build_sql(x, " rlike ", y),
-      `%regexp%`  = function(x, y) dbplyr::build_sql(x, " regexp ", y)
+      `%like%` = function(x, y) dbplyr::build_sql(x, " LIKE ", y),
+      `%rlike%` = function(x, y) dbplyr::build_sql(x, " RLIKE ", y),
+      `%regexp%` = function(x, y) dbplyr::build_sql(x, " REGEXP ", y),
+      grepl = function(x, y) dbplyr::build_sql(y, " RLIKE ", x),
+      transform = function(expr, func) {
+        sprintf(
+          "TRANSFORM(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      filter = function(expr, func) {
+        sprintf(
+          "FILTER(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      aggregate = function(expr, start, merge, finish = ~ .x) {
+        sprintf(
+          "AGGREGATE(%s, %s, %s, %s)",
+          dbplyr::build_sql(expr),
+          dbplyr::build_sql(start),
+          build_sql_fn(merge),
+          build_sql_fn(finish)
+        ) %>%
+          dbplyr::sql()
+      },
+      exists = function(expr, pred) {
+        sprintf(
+          "EXISTS(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(pred)
+        ) %>%
+          dbplyr::sql()
+      },
+      zip_with = function(left, right, func) {
+        sprintf(
+          "ZIP_WITH(%s, %s, %s)",
+          dbplyr::build_sql(left),
+          dbplyr::build_sql(right),
+          build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      array_sort = function(expr, func = ~ as.integer(sign(.x - .y))) {
+        sprintf(
+          "ARRAY_SORT(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      map_filter = function(expr, func) {
+        sprintf(
+          "MAP_FILTER(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      forall = function(expr, pred) {
+        sprintf(
+          "FORALL(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(pred)
+        ) %>%
+          dbplyr::sql()
+      },
+      transform_keys = function(expr, func) {
+        sprintf(
+          "TRANSFORM_KEYS(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      transform_values = function(expr, func) {
+        sprintf(
+          "TRANSFORM_VALUES(%s, %s)", dbplyr::build_sql(expr), build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      },
+      map_zip_with = function(map1, map2, func) {
+        sprintf(
+          "MAP_ZIP_WITH(%s, %s, %s)",
+          dbplyr::build_sql(map1),
+          dbplyr::build_sql(map2),
+          build_sql_fn(func)
+        ) %>%
+          dbplyr::sql()
+      }
     ),
 
     aggregate = dbplyr::sql_translator(
@@ -101,7 +182,7 @@ sql_translate_env.spark_connection <- function(con) {
       n_distinct = function(...) dbplyr::build_sql("count(DISTINCT", list(...), ")"),
       cor = dbplyr::sql_prefix("corr"),
       cov = dbplyr::sql_prefix("covar_samp"),
-      sd =  dbplyr::sql_prefix("stddev_samp"),
+      sd = dbplyr::sql_prefix("stddev_samp"),
       var = dbplyr::sql_prefix("var_samp")
     ),
 
@@ -123,45 +204,62 @@ sql_translate_env.spark_connection <- function(con) {
           order = order
         )
       },
-      count = function() dbplyr::win_over(
-        dbplyr::sql("count(*)"),
-        partition = dbplyr::win_current_group()
-      ),
+      count = function() {
+        dbplyr::win_over(
+          dbplyr::sql("count(*)"),
+          partition = dbplyr::win_current_group()
+        )
+      },
       n_distinct = dbplyr::win_absent("distinct"),
       cor = win_recycled_params("corr"),
-      cov =  win_recycled_params("covar_samp"),
-      sd =  dbplyr::win_recycled("stddev_samp"),
+      cov = win_recycled_params("covar_samp"),
+      sd = dbplyr::win_recycled("stddev_samp"),
       var = dbplyr::win_recycled("var_samp"),
       cumprod = function(x) {
         dbplyr::build_sql(
           "exp(",
           dbplyr::win_over(
-            dbplyr::build_sql("sum(if(", x,
-                              "= 0, 0, ln(abs(", x,
-                              "))))"),
+            dbplyr::build_sql(
+              "sum(if(", x,
+              "= 0, 0, ln(abs(", x,
+              "))))"
+            ),
             partition = dbplyr::win_current_group(),
             order = dbplyr::win_current_order()
           ), ") * (1 - 2 * pmod(",
           # count number of negatives up to current row
           #   and adjust sign accordingly
           dbplyr::win_over(
-            dbplyr::build_sql("sum(if(", x,
-                              ">= 0, 0, 1))"),
+            dbplyr::build_sql(
+              "sum(if(", x,
+              ">= 0, 0, 1))"
+            ),
             partition = dbplyr::win_current_group(),
             order = dbplyr::win_current_order()
           ), ", 2)) * if(",
           # if there's a zero then all cumprod after that row
           #   vanish
           dbplyr::win_over(
-            dbplyr::build_sql("min(abs(", x,
-                              "))"),
+            dbplyr::build_sql(
+              "min(abs(", x,
+              "))"
+            ),
             partition = dbplyr::win_current_group(),
             order = dbplyr::win_current_order()
           ), "= 0, 0, 1)"
         )
       }
     )
+  )
+}
 
+build_sql_fn <- function(fn) {
+  as.character(
+    if (rlang::is_formula(fn)) {
+      process_lambda(fn)
+    } else {
+      fn
+    }
   )
 }
 
