@@ -5,15 +5,15 @@ stream_read_generic_type <- function(sc,
                                      type,
                                      name,
                                      columns = NULL,
-                                     stream_options = list())
-{
+                                     stream_options = list()) {
   switch(type,
     csv = {
       spark_csv_read(
         sc,
         spark_normalize_path(path),
         stream_options,
-        columns)
+        columns
+      )
     },
     {
       spark_session(sc) %>%
@@ -29,8 +29,7 @@ stream_read_generic <- function(sc,
                                 name,
                                 columns,
                                 stream_options,
-                                load = FALSE)
-{
+                                load = FALSE) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   schema <- NULL
@@ -40,11 +39,12 @@ stream_read_generic <- function(sc,
 
   if (identical(columns, NULL)) {
     reader <- stream_read_generic_type(sc,
-                                       path,
-                                       type,
-                                       name,
-                                       columns = columns,
-                                       stream_options = stream_options)
+      path,
+      type,
+      name,
+      columns = columns,
+      stream_options = stream_options
+    )
     schema <- invoke(reader, "schema")
   }
   else if ("spark_jobj" %in% class(columns)) {
@@ -86,16 +86,16 @@ stream_read_generic <- function(sc,
   tbl(sc, name)
 }
 
-stream_write_generic <- function(x, path, type, mode, trigger, checkpoint, stream_options)
-{
+stream_write_generic <- function(x, path, type, mode, trigger, checkpoint, stream_options) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sdf <- spark_dataframe(x)
   sc <- spark_connection(x)
   mode <- match.arg(as.character(mode), choices = c("append", "complete", "update"))
 
-  if (!sdf_is_streaming(sdf))
+  if (!sdf_is_streaming(sdf)) {
     stop("DataFrame requires streaming context. Use `stream_read_*()` to read from streams.")
+  }
 
   streamOptions <- invoke(sdf, "writeStream") %>%
     invoke("format", type)
@@ -158,7 +158,6 @@ stream_write_generic <- function(x, path, type, mode, trigger, checkpoint, strea
 #' stream <- stream_read_csv(sc, csv_path) %>% stream_write_csv("csv-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -173,30 +172,32 @@ stream_read_csv <- function(sc,
                             charset = "UTF-8",
                             null_value = NULL,
                             options = list(),
-                            ...)
-{
+                            ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   infer_schema <- identical(columns, NULL) || is.character(columns)
 
-  streamOptions <- spark_csv_options(header = header,
-                                     inferSchema = infer_schema,
-                                     delimiter = delimiter,
-                                     quote = quote,
-                                     escape = escape,
-                                     charset = charset,
-                                     nullValue = null_value,
-                                     options = options)
+  streamOptions <- spark_csv_options(
+    header = header,
+    inferSchema = infer_schema,
+    delimiter = delimiter,
+    quote = quote,
+    escape = escape,
+    charset = charset,
+    nullValue = null_value,
+    options = options
+  )
 
 
   stream_read_generic(sc,
-                      path = path,
-                      type = "csv",
-                      name = name,
-                      columns = columns,
-                      stream_options = streamOptions)
+    path = path,
+    type = "csv",
+    name = name,
+    columns = columns,
+    stream_options = streamOptions
+  )
 }
 
 #' Write CSV Stream
@@ -228,7 +229,6 @@ stream_read_csv <- function(sc,
 #' stream <- stream_read_csv(sc, csv_path) %>% stream_write_csv("csv-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -244,26 +244,28 @@ stream_write_csv <- function(x,
                              charset = "UTF-8",
                              null_value = NULL,
                              options = list(),
-                             ...)
-{
+                             ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
-  streamOptions <- spark_csv_options(header = header,
-                                     inferSchema = NULL,
-                                     delimiter = delimiter,
-                                     quote = quote,
-                                     escape = escape,
-                                     charset = charset,
-                                     nullValue = null_value,
-                                     options = options)
+  streamOptions <- spark_csv_options(
+    header = header,
+    inferSchema = NULL,
+    delimiter = delimiter,
+    quote = quote,
+    escape = escape,
+    charset = charset,
+    nullValue = null_value,
+    options = options
+  )
 
   stream_write_generic(x,
-                       path = path,
-                       type = "csv",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = streamOptions)
+    path = path,
+    type = "csv",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = streamOptions
+  )
 }
 
 #' Write Memory Stream
@@ -289,7 +291,6 @@ stream_write_csv <- function(x,
 #' stream <- stream_read_csv(sc, csv_path) %>% stream_write_memory("csv-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -299,37 +300,42 @@ stream_write_memory <- function(x,
                                 trigger = stream_trigger_interval(),
                                 checkpoint = file.path("checkpoints", name, random_string("")),
                                 options = list(),
-                                ...)
-{
+                                ...) {
   sc <- spark_connection(x)
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   if (missing(mode)) {
     mode <- "append"
-    tryCatch({
-      queryPlan <- spark_dataframe(x) %>% invoke("queryExecution") %>% invoke("analyzed")
-      tryMode <- invoke_static(sc, "org.apache.spark.sql.streaming.OutputMode", "Complete")
-      invoke_static(
-        sc,
-        "org.apache.spark.sql.catalyst.analysis.UnsupportedOperationChecker",
-        "checkForStreaming",
-        queryPlan,
-        tryMode
-      )
+    tryCatch(
+      {
+        queryPlan <- spark_dataframe(x) %>%
+          invoke("queryExecution") %>%
+          invoke("analyzed")
+        tryMode <- invoke_static(sc, "org.apache.spark.sql.streaming.OutputMode", "Complete")
+        invoke_static(
+          sc,
+          "org.apache.spark.sql.catalyst.analysis.UnsupportedOperationChecker",
+          "checkForStreaming",
+          queryPlan,
+          tryMode
+        )
 
-      mode <- "complete"
-    }, error = function(e){
+        mode <- "complete"
+      },
+      error = function(e) {
 
-    })
+      }
+    )
   }
 
   stream_write_generic(x,
-                       path = name,
-                       type = "memory",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = name,
+    type = "memory",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
 
 #' Read Text Stream
@@ -353,7 +359,6 @@ stream_write_memory <- function(x,
 #' stream <- stream_read_text(sc, text_path) %>% stream_write_text("text-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -361,18 +366,18 @@ stream_read_text <- function(sc,
                              path,
                              name = NULL,
                              options = list(),
-                             ...)
-{
+                             ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = path,
-                      type = "text",
-                      name = name,
-                      columns = list(line = "character"),
-                      stream_options = options)
+    path = path,
+    type = "text",
+    name = name,
+    columns = list(line = "character"),
+    stream_options = options
+  )
 }
 
 #' Write Text Stream
@@ -398,7 +403,6 @@ stream_read_text <- function(sc,
 #' stream <- stream_read_text(sc, text_path) %>% stream_write_text("text-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -408,19 +412,19 @@ stream_write_text <- function(x,
                               trigger = stream_trigger_interval(),
                               checkpoint = file.path(path, "checkpoints", random_string("")),
                               options = list(),
-                              ...)
-{
+                              ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = path,
-                       type = "text",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = path,
+    type = "text",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
 
 #' Read JSON Stream
@@ -437,14 +441,13 @@ stream_write_text <- function(x,
 #' sc <- spark_connect(master = "local")
 #'
 #' dir.create("json-in")
-#' jsonlite::write_json(list(a = c(1,2), b = c(10,20)), "json-in/data.json")
+#' jsonlite::write_json(list(a = c(1, 2), b = c(10, 20)), "json-in/data.json")
 #'
 #' json_path <- file.path("file://", getwd(), "json-in")
 #'
 #' stream <- stream_read_json(sc, json_path) %>% stream_write_json("json-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -453,18 +456,18 @@ stream_read_json <- function(sc,
                              name = NULL,
                              columns = NULL,
                              options = list(),
-                             ...)
-{
+                             ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = path,
-                      type = "json",
-                      name = name,
-                      columns = columns,
-                      stream_options = options)
+    path = path,
+    type = "json",
+    name = name,
+    columns = columns,
+    stream_options = options
+  )
 }
 
 #' Write JSON Stream
@@ -481,14 +484,13 @@ stream_read_json <- function(sc,
 #' sc <- spark_connect(master = "local")
 #'
 #' dir.create("json-in")
-#' jsonlite::write_json(list(a = c(1,2), b = c(10,20)), "json-in/data.json")
+#' jsonlite::write_json(list(a = c(1, 2), b = c(10, 20)), "json-in/data.json")
 #'
 #' json_path <- file.path("file://", getwd(), "json-in")
 #'
 #' stream <- stream_read_json(sc, json_path) %>% stream_write_json("json-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -498,19 +500,19 @@ stream_write_json <- function(x,
                               trigger = stream_trigger_interval(),
                               checkpoint = file.path(path, "checkpoints", random_string("")),
                               options = list(),
-                              ...)
-{
+                              ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = path,
-                       type = "json",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = path,
+    type = "json",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
 
 #' Read Parquet Stream
@@ -531,7 +533,6 @@ stream_write_json <- function(x,
 #' stream <- stream_read_parquet(sc, "parquet-in") %>% stream_write_parquet("parquet-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -540,18 +541,18 @@ stream_read_parquet <- function(sc,
                                 name = NULL,
                                 columns = NULL,
                                 options = list(),
-                                ...)
-{
+                                ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = path,
-                      type = "parquet",
-                      name = name,
-                      columns = columns,
-                      stream_options = options)
+    path = path,
+    type = "parquet",
+    name = name,
+    columns = columns,
+    stream_options = options
+  )
 }
 
 #' Write Parquet Stream
@@ -572,7 +573,6 @@ stream_read_parquet <- function(sc,
 #' stream <- stream_read_parquet(sc, "parquet-in") %>% stream_write_parquet("parquet-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -582,19 +582,19 @@ stream_write_parquet <- function(x,
                                  trigger = stream_trigger_interval(),
                                  checkpoint = file.path(path, "checkpoints", random_string("")),
                                  options = list(),
-                                 ...)
-{
+                                 ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = path,
-                       type = "parquet",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = path,
+    type = "parquet",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
 
 #' Read ORC Stream
@@ -615,7 +615,6 @@ stream_write_parquet <- function(x,
 #' stream <- stream_read_orc(sc, "orc-in") %>% stream_write_orc("orc-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -624,18 +623,18 @@ stream_read_orc <- function(sc,
                             name = NULL,
                             columns = NULL,
                             options = list(),
-                            ...)
-{
+                            ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = path,
-                      type = "orc",
-                      name = name,
-                      columns = columns,
-                      stream_options = options)
+    path = path,
+    type = "orc",
+    name = name,
+    columns = columns,
+    stream_options = options
+  )
 }
 
 #' Write a ORC Stream
@@ -656,7 +655,6 @@ stream_read_orc <- function(sc,
 #' stream <- stream_read_orc(sc, "orc-in") %>% stream_write_orc("orc-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -666,19 +664,19 @@ stream_write_orc <- function(x,
                              trigger = stream_trigger_interval(),
                              checkpoint = file.path(path, "checkpoints", random_string("")),
                              options = list(),
-                             ...)
-{
+                             ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = path,
-                       type = "orc",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = path,
+    type = "orc",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
 
 #' Read Kafka Stream
@@ -705,25 +703,24 @@ stream_write_orc <- function(x,
 #'   stream_write_kafka(options = write_options)
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
 stream_read_kafka <- function(sc,
                               name = NULL,
                               options = list(),
-                              ...)
-{
+                              ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = NULL,
-                      type = "kafka",
-                      name = name,
-                      columns = FALSE,
-                      stream_options = options)
+    path = NULL,
+    type = "kafka",
+    name = name,
+    columns = FALSE,
+    stream_options = options
+  )
 }
 
 #' Write Kafka Stream
@@ -750,7 +747,6 @@ stream_read_kafka <- function(sc,
 #'   stream_write_kafka(options = write_options)
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -759,19 +755,19 @@ stream_write_kafka <- function(x,
                                trigger = stream_trigger_interval(),
                                checkpoint = file.path("checkpoints", random_string("")),
                                options = list(),
-                               ...)
-{
+                               ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = NULL,
-                       type = "kafka",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = NULL,
+    type = "kafka",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
 
 #' Read Socket Stream
@@ -790,7 +786,6 @@ stream_write_kafka <- function(x,
 #' # Start socket server from terminal, example: nc -lk 9999
 #' stream <- stream_read_socket(sc, options = list(host = "localhost", port = 9999))
 #' stream
-#'
 #' }
 #'
 #' @export
@@ -798,18 +793,18 @@ stream_read_socket <- function(sc,
                                name = NULL,
                                columns = NULL,
                                options = list(),
-                               ...)
-{
+                               ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = NULL,
-                      type = "socket",
-                      name = name,
-                      columns = FALSE,
-                      stream_options = options)
+    path = NULL,
+    type = "socket",
+    name = name,
+    columns = FALSE,
+    stream_options = options
+  )
 }
 
 #' Write Console Stream
@@ -825,12 +820,13 @@ stream_read_socket <- function(sc,
 #'
 #' sc <- spark_connect(master = "local")
 #'
-#' sdf_len(sc, 10) %>% dplyr::transmute(text = as.character(id)) %>% spark_write_text("text-in")
+#' sdf_len(sc, 10) %>%
+#'   dplyr::transmute(text = as.character(id)) %>%
+#'   spark_write_text("text-in")
 #'
 #' stream <- stream_read_text(sc, "text-in") %>% stream_write_console()
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -838,19 +834,19 @@ stream_write_console <- function(x,
                                  mode = c("append", "complete", "update"),
                                  options = list(),
                                  trigger = stream_trigger_interval(),
-                                 ...)
-{
+                                 ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = NULL,
-                       type = "console",
-                       mode = mode,
-                       trigger = trigger,
-                       checkpoint = NULL,
-                       stream_options = options)
+    path = NULL,
+    type = "console",
+    mode = mode,
+    trigger = trigger,
+    checkpoint = NULL,
+    stream_options = options
+  )
 }
 
 #' Read Delta Stream
@@ -876,7 +872,6 @@ stream_write_console <- function(x,
 #'   stream_write_json("json-out")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -884,19 +879,19 @@ stream_read_delta <- function(sc,
                               path,
                               name = NULL,
                               options = list(),
-                              ...)
-{
+                              ...) {
   spark_require_version(sc, "2.0.0", "Spark streaming")
 
   name <- name %||% random_string("sparklyr_tmp_")
 
   stream_read_generic(sc,
-                      path = path,
-                      type = "delta",
-                      name = name,
-                      columns = FALSE,
-                      stream_options = options,
-                      load = TRUE)
+    path = path,
+    type = "delta",
+    name = name,
+    columns = FALSE,
+    stream_options = options,
+    load = TRUE
+  )
 }
 
 #' Write Delta Stream
@@ -924,7 +919,6 @@ stream_read_delta <- function(sc,
 #' stream <- stream_read_text(sc, text_path) %>% stream_write_delta(path = "delta-test")
 #'
 #' stream_stop(stream)
-#'
 #' }
 #'
 #' @export
@@ -933,17 +927,17 @@ stream_write_delta <- function(x,
                                mode = c("append", "complete", "update"),
                                checkpoint = file.path("checkpoints", random_string("")),
                                options = list(),
-                               ...)
-{
+                               ...) {
   spark_require_version(spark_connection(x), "2.0.0", "Spark streaming")
 
   sc <- spark_connection(x)
 
   stream_write_generic(x,
-                       path = path,
-                       type = "delta",
-                       mode = mode,
-                       trigger = FALSE,
-                       checkpoint = checkpoint,
-                       stream_options = options)
+    path = path,
+    type = "delta",
+    mode = mode,
+    trigger = FALSE,
+    checkpoint = checkpoint,
+    stream_options = options
+  )
 }
