@@ -1,17 +1,19 @@
 is.installed <- function(package) {
-  is.element(package, installed.packages()[,1])
+  is.element(package, installed.packages()[, 1])
 }
 
 utils_starts_with <- function(lhs, rhs) {
-  if (nchar(lhs) < nchar(rhs))
+  if (nchar(lhs) < nchar(rhs)) {
     return(FALSE)
+  }
   identical(substring(lhs, 1, nchar(rhs)), rhs)
 }
 
 aliased_path <- function(path) {
   home <- path.expand("~/")
-  if (utils_starts_with(path, home))
+  if (utils_starts_with(path, home)) {
     path <- file.path("~", substring(path, nchar(home) + 1))
+  }
   path
 }
 
@@ -26,7 +28,7 @@ transpose_list <- function(list) {
 #' @param prefix A length-one character vector.
 #' @export
 random_string <- function(prefix = "table") {
-  basename(tempfile(prefix))
+  paste0(prefix, "_", gsub("-", "_", uuid::UUIDgenerate()))
 }
 
 printf <- function(fmt, ...) {
@@ -79,8 +81,9 @@ spark_param_deprecated <- function(param, version = "3.x") {
 regex_replace <- function(string, ...) {
   dots <- list(...)
   nm <- names(dots)
-  for (i in seq_along(dots))
+  for (i in seq_along(dots)) {
     string <- gsub(nm[[i]], dots[[i]], string, perl = TRUE)
+  }
   string
 }
 
@@ -95,8 +98,9 @@ spark_sanitize_names <- function(names, config) {
   # the Spark API.
 
   # sanitize names by default, but opt out with global option
-  if (!isTRUE(spark_config_value(config, "sparklyr.sanitize.column.names", TRUE)))
+  if (!isTRUE(spark_config_value(config, "sparklyr.sanitize.column.names", TRUE))) {
     return(names)
+  }
 
   # begin transforming names
   oldNames <- newNames <- names
@@ -111,10 +115,11 @@ spark_sanitize_names <- function(names, config) {
     )
 
     # on success, return the transformed name
-    if (!is.na(transformed))
+    if (!is.na(transformed)) {
       transformed
-    else
+    } else {
       name
+    }
   }))
 
   # replace spaces with '_', and discard other characters
@@ -137,10 +142,8 @@ spark_sanitize_names <- function(names, config) {
   )
 
   if (verbose) {
-
     changedIdx <- which(oldNames != newNames)
     if (length(changedIdx)) {
-
       changedOldNames <- oldNames[changedIdx]
       changedNewNames <- newNames[changedIdx]
 
@@ -160,7 +163,6 @@ spark_sanitize_names <- function(names, config) {
       )
 
       message(msg)
-
     }
   }
 
@@ -209,8 +211,9 @@ enumerate <- function(object, f, ...) {
 path_program <- function(program, fmt = NULL) {
   fmt <- fmt %||% "program '%s' is required but not available on the path"
   path <- Sys.which(program)
-  if (!nzchar(path))
+  if (!nzchar(path)) {
     stopf(fmt, program, call. = FALSE)
+  }
   path
 }
 
@@ -224,12 +227,13 @@ split_chunks <- function(x, chunk_size) {
 
   # return early when chunk_size > length of vector
   n <- length(x)
-  if (n <= chunk_size)
+  if (n <= chunk_size) {
     return(list(x))
+  }
 
   # compute ranges for subsetting
   starts <- seq(1, n, by = chunk_size)
-  ends   <- c(seq(chunk_size, n - 1, by = chunk_size), n)
+  ends <- c(seq(chunk_size, n - 1, by = chunk_size), n)
 
   # apply our subsetter
   mapply(function(start, end) {
@@ -250,10 +254,11 @@ trim_whitespace <- function(strings) {
 }
 
 split_separator <- function(sc) {
-  if (inherits(sc, "livy_connection"))
+  if (inherits(sc, "livy_connection")) {
     list(regexp = "\\|~\\|", plain = "|~|")
-  else
-    list(regexp = "\31", plain = "\31")
+  } else {
+    list(regexp = "\3", plain = "\3")
+  }
 }
 
 resolve_fn <- function(fn, ...) {
@@ -269,7 +274,7 @@ is.tbl_spark <- function(x) {
   if (length(dest) != length(value)) stop("Assignment must contain same number of elements")
 
   for (i in seq_along(dest)) {
-    assign(dest[i], value[i], envir = sys.frame(which =sys.parent(n = 1)))
+    assign(dest[[i]], value[[i]], envir = sys.frame(which = sys.parent(n = 1)))
   }
 
   invisible(NULL)
@@ -278,3 +283,48 @@ is.tbl_spark <- function(x) {
 sort_named_list <- function(lst, ...) {
   lst[order(names(lst), ...)]
 }
+
+# syntax sugar for calling dplyr methods with do.call and a non-trivial variable
+# list of args
+`%>>%` <- function(x, fn) {
+  fn_call <- function(largs) {
+    do.call(fn, append(list(x), as.list(largs)))
+  }
+
+  fn_call
+}
+
+`%@%` <- function(fn, largs) fn(largs)
+
+pcre_to_java <- function(regex) {
+  regex %>%
+    gsub("\\[:alnum:\\]", "A-Za-z0-9", .) %>%
+    gsub("\\[:alpha:\\]", "A-Za-z", .) %>%
+    gsub("\\[:ascii:\\]", paste0("\\\\", "x00", "-", "\\\\", "x7F"), .) %>%
+    gsub("\\[:blank:\\]", " \\\\t", .) %>%
+    gsub("\\[:cntrl:\\]", paste0("\\\\", "x00", "-", "\\\\", "x1F", "\\\\", "x7F"), .) %>%
+    gsub("\\[:digit:\\]", "0-9", .) %>%
+    gsub("\\[:graph:\\]", paste0("\\\\", "x21", "-", "\\\\", "x7E"), .) %>%
+    gsub("\\[:lower:\\]", "a-z", .) %>%
+    gsub("\\[:print:\\]", paste0("\\\\", "x20", "-", "\\\\", "x7E"), .) %>%
+    gsub("\\[:punct:\\]",
+         paste0("\\\\", "x21", "-", "\\\\", "x2F",
+                "\\\\", "x3A", "-", "\\\\", "x40",
+                "\\\\", "x5B", "-", "\\\\", "x60",
+                "\\\\", "x7B", "-", "\\\\", "x7E"),
+         .
+        ) %>%
+    gsub("\\[:space:\\]",
+         paste0(" ",
+                "\\\\", "t",
+                "\\\\", "r",
+                "\\\\", "n",
+                "\\\\", "v",
+                "\\\\", "f"
+         ),
+         .
+        ) %>%
+    gsub("\\[:upper:\\]", "A-Z", .) %>%
+    gsub("\\[:word:\\]", "A-Za-z0-9_", .) %>%
+    gsub("\\[:xdigit:\\]", "0-9a-fA-F", .)
+}
